recollect
A Windows ONLY plugin created to provide everything needed to create as efficiently and safely as possible.
Libraries
- core/presentation/colour_picker
- core/presentation/infrastructure/color_selector
- core/presentation/infrastructure/icon_selector
- core/presentation/infrastructure/increment_decrement_field
- core/presentation/infrastructure/selectable_grid
- core/presentation/infrastructure/text_item_selector
- core/presentation/infrastructure/theme
- modules/colour
- The Collect Colour system — a multi-format colour class that goes beyond Flutter's Color.
- modules/colour_picker
- modules/idols
- A collection of dropdown menu and suggestion widgets with keyboard navigation.
- modules/moment
- modules/xtx
- recollect
- Collect — The Developer's Repertoire