IconItem class

An option that is displayed as an icon by a IconSelector.

Two IconItems are considered to be equal if they have the same id.

Constructors

IconItem({required String id, required IconData icon})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
icon IconData
The icon that is displayed.
final
id String
The value that identifies this item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override