itemBuilder property
Builds each item on the grid.
This method is called for each item in items, to build its visual representation.
The provided onTap must be called when the item is tapped.
Implementation
final SelectableGridItemBuilder<GridItemType> itemBuilder;