items property
The items that will be displayed on the grid.
For each item, itemBuilder is called to build its visual representation.
Implementation
final List<GridItemType> items;
The items that will be displayed on the grid.
For each item, itemBuilder is called to build its visual representation.
final List<GridItemType> items;