onItemActivated property
Called when the user activates an item on the grid.
The activation can be performed by:
- Pressing UP ARROW or DOWN ARROW.
- Pressing LEFT ARROW or RIGHT ARROW.
Implementation
final ValueChanged<GridItemType?>? onItemActivated;
Called when the user activates an item on the grid.
The activation can be performed by:
final ValueChanged<GridItemType?>? onItemActivated;