value property
GridItemType?
value
final
The currently selected value or null if no item is selected.
Implementation
final GridItemType? value;
The currently selected value or null if no item is selected.
final GridItemType? value;