SelectableGridItemBuilder<T> typedef

SelectableGridItemBuilder<T> = Widget Function(BuildContext context, T item, bool isActive, VoidCallback onTap)

Builds a grid item.

isActive is true if item is the currently active item on the grid, or false otherwise.

The active item is the currently focused item in the grid, which can be selected by pressing ENTER.

The provided onTap must be called when the button is tapped.

Implementation

typedef SelectableGridItemBuilder<T> =
    Widget Function(
      BuildContext context,
      T item,
      bool isActive,
      VoidCallback onTap,
    );