core/presentation/infrastructure/text_item_selector library

Classes

TextItem
An option that is displayed as text by a TextItemSelector.
TextItemSelector
A selection control, which displays a button with the selected text, and upon tap, displays a popover list of available texts, from which the user can select a different text.

Functions

defaultPopoverListItemBuilder(BuildContext context, TextItem item, bool isActive, VoidCallback onTap) Widget