TextItem class

An option that is displayed as text by a TextItemSelector.

Two TextItems are considered to be equal if they have the same id.

Constructors

TextItem({required String id, required String label})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
The value that identifies this item.
final
label String
The text that is displayed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override