DD top-level constant

String const DD

Day of Month (Padded)


Format: 01 02 ... 30 31

Summary: A two-digit, zero-padded day of the month.

Details: This ensures that the day always occupies two characters. This is required for fixed-width layouts and digital clock displays where jumping text widths would be visually distracting.

Implementation

const String DD = 'DD';