MM top-level constant

String const MM

Month (Padded)


Format: 01 02 ... 11 12

Summary: A two-digit, zero-padded numerical month.

Details: Ensures that the month value is always two digits long. This is the standard for numerical date formats like MM/DD/YYYY.

Implementation

const String MM = 'MM';