formatStyle property
The token sequence used by format to produce a formatted string.
Defaults to defaultFormatStyle, which produces output like:
"The 19th of February 2026 at 14:35:00"
Implementation
List<String> formatStyle;
The token sequence used by format to produce a formatted string.
Defaults to defaultFormatStyle, which produces output like:
"The 19th of February 2026 at 14:35:00"
List<String> formatStyle;