isNegative property
bool
get
isNegative
Returns true if this period represents a negative duration (going
backward in time).
Implementation
bool get isNegative => _period < 0;
Returns true if this period represents a negative duration (going
backward in time).
bool get isNegative => _period < 0;