a top-level constant

String const a

AM/PM (Lowercase)


Format: am pm

Summary: The meridiem indicator in lowercase.

Details: A stylistic alternative to the A token. It is often used in modern, minimalist web design or mobile apps where a less prominent "am/pm" indicator is desired.

Implementation

const String a = 'a';