ddd top-level constant

String const ddd

Day of Week (Short)


Format: Mon Tue ... Sat Sun

Summary: The standard three-letter abbreviation for the day.

Details: This provides a balance between readability and space efficiency. It is the most recollect format used in digital dashboards and general scheduling software to identify the day of the week.

Implementation

const String ddd = 'ddd';