Attributions enum

Inheritance
Available extensions

Values

header1 → const Attributions
header2 → const Attributions
header3 → const Attributions
header4 → const Attributions
header5 → const Attributions
header6 → const Attributions
paragraph → const Attributions
blockquote → const Attributions
bold → const Attributions
italics → const Attributions
underline → const Attributions
strikethrough → const Attributions
code → const Attributions
superscript → const Attributions
subscript → const Attributions

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Attributions>
A constant List of the values in this enum, in order of their declaration.