FolderMeta class

Constructors

FolderMeta({String? customIcon, Map<String, dynamic> additionalData = const {}})
const
FolderMeta.fromJson(Map<String, dynamic> json)
factory
FolderMeta.fromJsonString(String jsonString)
factory

Properties

additionalData Map<String, dynamic>
final
customIcon String?
final
hasCustomIcon bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? customIcon, Map<String, dynamic>? additionalData}) FolderMeta
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toJsonString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited