core/presentation/infrastructure/icon_selector library
Classes
- IconItem
- An option that is displayed as an icon by a IconSelector.
- IconSelector
- A selection control, which displays a button with the selected icon, and upon tap, displays a popover list of available icons, from which the user can select a different icon.