core/presentation/infrastructure/theme
library
Constants
-
The horizontal padding of the primary app menu buttons, e.g., "File", "Edit".
-
titleActionIconColor
→ const Color
-
The color of the icons that appear next to the document title.
-
toolbarBackgroundColor
→ const Color
-
The background color of the app toolbar, i.e., the toolbar with options for font
family, font size, text alignment.
-
toolbarButtonHoveredColor
→ const Color
-
The background color of a hovered button on the toolbar.
-
toolbarButtonPressedColor
→ const Color
-
The background color of a pressed button on the toolbar.
-
toolbarButtonSelectedColor
→ const Color
-
The background color of a selected button on the toolbar, i.e., the color of a
bold button when the selection is bold.
-
toolbarDividerColor
→ const Color
-
The color of the vertical divider of the toolbar.
-
windowBackgroundColor
→ const Color
-
The background color of the window panes, such as the background of the
app header/ribbon.