modules/colour_picker library
Classes
- CheckerPainter
- Painter for chess type alpha background in slider track widget.
- ColourIndicator
- Simple round color indicator.
- ColourPicker
- The default layout of Color Picker.
- ColourPickerArea
- Provide Rectangle & Circle 2 categories, 10 variations of palette widget.
- ColourPickerHueRing
- Provide Hue Ring with HSV Rectangle of palette widget.
- ColourPickerInput
- Provide hex input wiget for 3/6/8 digits.
- ColourPickerLabel
- Provide label for color information.
- ColourPickerSlider
- 9 track types for slider picker widget.
- HSLWithHueColourPainter
- Painter for SL mixture.
- HSLWithLightnessColourPainter
- Painter for HS mixture.
- HSLWithSaturationColourPainter
- Painter for HL mixture.
- HSVWithHueColourPainter
- Painter for SV mixture.
- HSVWithSaturationColourPainter
- Painter for HV mixture.
- HSVWithValueColourPainter
- Painter for HS mixture.
- HUEColorWheelPainter
- Painter for hue color wheel.
- HueRingPainter
- Painter for hue ring.
- HueRingPicker
- The Color Picker with HUE Ring & HSV model.
- IndicatorPainter
- Painter for chess type alpha background in color indicator widget.
- RGBWithBlueColourPainter
- Painter for RG mixture.
- RGBWithGreenColourPainter
- Painter for RB mixture.
- RGBWithRedColourPainter
- Painter for GB mixture.
- SlidePicker
- The Color Picker with sliders only. Support HSV, HSL and RGB color mod el.
- ThumbPainter
- Painter for thumb of slider.
- TrackPainter
- Painter for all kinds of track types.
- UpperCaseTextFormatter
- Uppercase text formater
Enums
- ColorLabelType
- Color information label type.
- ColorModel
- Types for slider picker widget.
- PaletteType
- Palette types for color picker area widget.
- TrackType
- Track types for slider picker.
Constants
-
x11Colours
→ const Map<
String, Color>
Functions
-
colorFromName(
String val) → Color?