MetadataKeys class
Centralized constants for metadata keys used in XTX nodes
This class contains all the string keys used for node metadata, eliminating magic strings scattered throughout the codebase.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- blockType → const String
- Block type metadata key
-
blockTypes
→ const List<
String> - List of all block type values
- bold → const String
- Bold text formatting
- fontSize → const String
- Font size formatting
-
formattingKeys
→ const List<
String> - List of all text formatting keys
- header1 → const String
- Header level 1 block type
- header2 → const String
- Header level 2 block type
- header3 → const String
- Header level 3 block type
- header4 → const String
- Header level 4 block type
- header5 → const String
- Header level 5 block type
- header6 → const String
- Header level 6 block type
- italic → const String
- Italic text formatting
- paragraph → const String
- Paragraph block type (default)
- strikethrough → const String
- Strikethrough text formatting
- subscript → const String
- Subscript text formatting
- superscript → const String
- Superscript text formatting
- underline → const String
- Underline text formatting