AlignType enum
Defines alignment and sizing options for dropdown menus.
AlignType is used by menu widgets like SuggestionField and MenuDropDown to control how the dropdown menu is positioned and sized relative to its anchor widget.
Values
left- Dropdown aligns to the left edge of the anchorcenter- Dropdown is centered below the anchorright- Dropdown aligns to the right edge of the anchorfill- Dropdown fills the entire width of the anchor
Example Usage
SuggestionField(
items: ['Option 1', 'Option 2'],
alignDropdown: AlignType.fill, // Dropdown fills full width
onSelected: (value) {},
)
Values
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited